"use strict";

/* eslint-disable no-console */

import React, { memo, useCallback, useEffect, useState } from 'react';
import { ScrollView, StyleSheet, Text, View } from 'react-native';
import { useShiki } from './SyntaxContext';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const DEBUG = true;
function _log(...args) {
  if (DEBUG) console.log('[SyntaxHighlighter]', ...args);
}
const styles = StyleSheet.create({
  container: {
    flex: 1
  },
  line: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
export const SyntaxHighlighter = /*#__PURE__*/memo(({
  code,
  language,
  theme,
  fontSize = 14
}) => {
  const {
    highlighter,
    isReady
  } = useShiki();
  const [tokens, setTokens] = useState([]);
  const [error, setError] = useState(null);
  const highlight = useCallback(async () => {
    if (!highlighter || !isReady) {
      _log('Highlighter not ready:', {
        highlighter: !!highlighter,
        isReady
      });
      return;
    }
    try {
      const loadedLangs = highlighter.getLoadedLanguages();
      _log('Available languages:', loadedLangs);
      const normalizedLang = language?.toLowerCase() || 'text';
      _log('Requested language:', normalizedLang);
      const langToUse = loadedLangs.includes(normalizedLang) ? normalizedLang : 'text';
      _log('Using language:', langToUse);

      // Get current theme info with theme argument
      const currentTheme = highlighter.getTheme(theme || 'default');
      _log('Current theme:', {
        name: currentTheme.name,
        type: currentTheme.type,
        tokenColors: currentTheme.tokenColors?.length
      });

      // Detailed tokenization attempt
      _log('Attempting tokenization with:', {
        codeLength: code.length,
        language: langToUse,
        themeName: currentTheme.name
      });
      const results = highlighter.codeToTokens(code.trim(), {
        lang: langToUse,
        theme: currentTheme.name
      });
      _log('Tokenization results:', {
        lineCount: results.tokens.length,
        totalTokens: results.tokens.flat().length,
        firstLine: results.tokens[0]?.map(t => ({
          content: t.content,
          color: t.color,
          fontStyle: t.fontStyle
        }))
      });
      setTokens(results.tokens);
      setError(null);
    } catch (err) {
      console.error('Highlighting error:', err);
      _log('Highlighting failed:', {
        error: err instanceof Error ? err.message : 'Unknown error',
        code: `${code.substring(0, 100)}...`
      });
      setError(err instanceof Error ? err.message : 'Failed to highlight code');
    }
  }, [code, language, theme, highlighter, isReady]);
  useEffect(() => {
    highlight();
  }, [highlight]);
  useEffect(() => {
    if (tokens.length > 0) {
      _log('Token analysis:', {
        lineCount: tokens.length,
        sample: tokens[0]?.slice(0, 2),
        colors: [...new Set(tokens.flat().map(t => t.color))]
      });
    }
  }, [tokens]);
  if (!isReady) {
    return /*#__PURE__*/_jsx(View, {
      style: styles.container,
      children: /*#__PURE__*/_jsx(Text, {
        style: {
          fontSize
        },
        children: code
      })
    });
  }
  if (error) {
    return /*#__PURE__*/_jsxs(View, {
      style: styles.container,
      children: [/*#__PURE__*/_jsx(Text, {
        style: {
          color: 'red'
        },
        children: error
      }), /*#__PURE__*/_jsx(Text, {
        style: {
          fontSize
        },
        children: code
      })]
    });
  }
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    style: styles.container,
    children: /*#__PURE__*/_jsx(View, {
      children: tokens.map((line, i) => /*#__PURE__*/_jsx(View, {
        style: styles.line,
        children: line.map((token, j) => /*#__PURE__*/_jsx(Text, {
          style: {
            color: token.color,
            fontSize,
            ...(token.fontStyle && token.fontStyle & 1 && {
              fontStyle: 'italic'
            }),
            ...(token.fontStyle && token.fontStyle & 2 && {
              fontWeight: 'bold'
            }),
            ...(token.bgColor && {
              backgroundColor: token.bgColor
            })
          },
          children: token.content
        }, `${i}-${j}`))
      }, i))
    })
  });
});
//# sourceMappingURL=SyntaxHighlighter.js.map